*********************
Principle 3: Dynamics
*********************

.. toctree::

   examples/integrator
   examples/controlled_integrator
   examples/controlled_integrator2
   examples/oscillator
   examples/controlled_oscillator
   examples/lorenz_attractor
